@@ -2,7 +2,7 @@ import json
 from typing import Union, Dict, Any, List
 
 # noinspection PyPackageRequirements
-from fhir.resources.bundle import Bundle
+from fhir.resources.bundle import Bundle, BundleEntry
 
 # noinspection PyPackageRequirements
 from fhir.resources.patient import Patient
@@ -31,8 +31,18 @@ class FhirLoader:
             raise Exception(f"resourceType {resource_type} is not Patient or Person")
 
     @staticmethod
-    def get_scoring_inputs(resource_json: str) -> List[ScoringInput]:
-        resource: Union[Patient, Person, Bundle] = FhirLoader.parse(
-            resource_json=resource_json
-        )
-        return FhirToAttributeDict.get_scoring_inputs_for_resource(resource)
+    def get_scoring_inputs(resource_json: Union[str, List[str]]) -> List[ScoringInput]:
+        if isinstance(resource_json, list):
+            # make it into a bundle
+            bundle = Bundle(type="collection")
+            bundle.total = len(resource_json)
+            bundle.entry = [
+                BundleEntry(resource=FhirLoader.parse(resource_json=resource_json_item))
+                for resource_json_item in resource_json
+            ]
+            return FhirToAttributeDict.get_scoring_inputs_for_resource(bundle)
+        else:
+            resource: Union[Patient, Person, Bundle] = FhirLoader.parse(
+                resource_json=resource_json
+            )
+            return FhirToAttributeDict.get_scoring_inputs_for_resource(resource)
