@@ -91,6 +91,7 @@ class Matcher:
         for source_resource in source:
             found_match: bool = False
             highest_scoring_match: Optional[MatchScore] = None
+            result_for_current_source: List[MatchScore] = []
             for target_resource in target:
                 score = ScoreCalculator.calculate_total_score(
                     rules=rules,
@@ -108,6 +109,7 @@ class Matcher:
                     matched=matched_threshold,
                     average_boost=score.average_boost,
                     average_score=score.average_score,
+                    total_score_unscaled=score.total_score_unscaled,
                 )
                 if (
                     not highest_scoring_match
@@ -116,8 +118,26 @@ class Matcher:
                     highest_scoring_match = match_score
                 if matched_threshold:
                     found_match = True
-                if not only_matches or matched_threshold:
-                    result.append(match_score)
+
+                result_for_current_source.append(match_score)
+
+            # now scale down the scores if highest score is over 1.0
+            if (
+                highest_scoring_match is not None
+                and highest_scoring_match.total_score > 1.0
+            ):
+                highest_match_total_score = highest_scoring_match.total_score
+                for score in result_for_current_source:
+                    score.total_score = score.total_score / highest_match_total_score
+                    score.matched = score.total_score >= self.match_threshold
+            # add to list
+            if only_matches:
+                result_for_current_source = [
+                    s for s in result_for_current_source if s.matched
+                ]
+            result = result + result_for_current_source
+
+            # if no match found, add the highest scoring match for troubleshooting
             if not found_match and highest_scoring_match is not None:
                 result.append(highest_scoring_match)
 
