@@ -4,7 +4,6 @@ from typing import List
 
 from helix_personmatching.logics.match_score import MatchScore
 from helix_personmatching.matchers.matcher import Matcher
-from helix_personmatching.models.scoring_option import ScoringOption
 
 
 def test_walgreens_match1() -> None:
@@ -23,14 +22,7 @@ def test_walgreens_match1() -> None:
         source_json=walgreens_person_json,
         target_json=bwell_master_person_json,
         verbose=True,
-        options=[
-            ScoringOption(
-                rule_name="Rule-050",
-                # weight=RuleWeight(
-                #     exact_match=1.0, partial_match=1.0, missing=0.5, boost=0.051
-                # ),
-            ),
-        ],
+        options=[],
     )
 
     assert len(scores) == 1
