@@ -1,4 +1,3 @@
-import dataclasses
 import json
 from pathlib import Path
 from typing import List
@@ -45,9 +44,7 @@ def test_walgreens_partial_match_with_extra_rule_and_custom_weights() -> None:
     print(f"score.matched: {score.matched}")
     assert score.matched is True
 
-    score_dict = dataclasses.asdict(score)
-
-    scores_json = json.dumps(score_dict, default=str)
+    scores_json = score.to_json()
     print(scores_json)
 
     print(f"score.total_score: {score.total_score}")
@@ -56,4 +53,4 @@ def test_walgreens_partial_match_with_extra_rule_and_custom_weights() -> None:
     with open(data_dir.joinpath("expected_scores.json")) as file:
         expected_scores = json.loads(file.read())
 
-    assert score_dict == expected_scores
+    assert json.loads(scores_json) == expected_scores
