@@ -17,7 +17,7 @@ class Attribute:
         name="name_use"
     )  # required, "usual | official | temp | nickname | anonymous | old | maiden"
     NAME_TEXT: AttributeEntry = AttributeEntry(name="name_text")
-    NAME_GIVEN: AttributeEntry = AttributeEntry(name="name_given")
+    NAME_GIVEN: AttributeEntry = AttributeEntry(name="name_given", nick_name_match=True)
     NAME_MIDDLE: AttributeEntry = AttributeEntry(name="name_middle")
     NAME_MIDDLE_INITIAL: AttributeEntry = AttributeEntry(name="name_middle_initial")
     NAME_FAMILY: AttributeEntry = AttributeEntry(name="name_family")
